##  Step 2: Create a Webhook
Create a PUSH webhook for the AUTOMATION_TRIGGERED event. You can do it in one of the following ways:
  * Option 1: in the Webhooks section of the administration area
  * Option 2: through the Webhooks API


To learn more about webhooks, see [Webhooks](https://help.sap.com/docs/leanix/ea/webhooks?locale=en-US&state=PRODUCTION&version=CLOUD "Listen to events in SAP LeanIX using webhooks.").
